diff -u alis-2.2beta5.dist/config.h alis-2.2beta5/config.h
--- alis-2.2beta5.dist/config.h	Fri Sep 14 20:55:31 2001
+++ alis-2.2beta5/config.h	Tue Jul  2 11:22:04 2002
@@ -7,7 +7,7 @@
 #define SERVICE_PASS     "mypassword"
 #define SERVICE_CTRLPASS "secretpassword" /* important */
 #define SERVICE_NAME     "List"
-#define SERVER_NAME      "127.0.0.1" /* host and IP both work now */
+#define SERVER_NAME      "127.0.0.1" /* host or IP, IPv4 or IPv6 */
 #define SERVER_PORT       6667
 #define SERVICE_DIST     "*" /* looks like it works only with "*" (ircd bug) 
 				(8/18/99)<syrk> most bugs are worth patching
diff -u alis-2.2beta5.dist/io.c alis-2.2beta5/io.c
--- alis-2.2beta5.dist/io.c	Tue Aug 14 16:27:05 2001
+++ alis-2.2beta5/io.c	Tue Jul  2 11:21:17 2002
@@ -14,51 +14,31 @@
 #include "io.h"
 #include "config.h"
 
+static struct addrinfo * gethostinfo(char const *host, int port);
+
 int SockOpen(const char *host, int clientPort)
 {
-    int sock;
-    struct sockaddr_in ad;
-    struct hostent *hp;
-
-    memset(&ad, 0, sizeof(ad));
-    ad.sin_family = AF_INET;
-
-    if ((hp = gethostbyname (host)) == NULL)
-        return -1;
-
-    /* vhost support code can be added here if desired */
+    int sock = -1;
+    struct addrinfo *hostres, *res;
 
-	/*
-	 * Add a check to make sure the address has a valid IPv4 or IPv6
-	 * length.  This prevents buffer spamming by a broken DNS.
-	 */
-	if (hp == NULL || (hp->h_length != 4 && hp->h_length != 8))
-	    return -1;
-
-	/*
-	 * FIXME: make this work for multihomed hosts.
-	 * We're toast if we get back multiple addresses and h_addrs[0]
-	 * (aka h_addr) is not one we can actually connect to; this happens
-	 * with multi-homed boxes.
-	 */
-	memcpy(&ad.sin_addr, hp->h_addr, hp->h_length);
-
-    ad.sin_port = htons(clientPort);
-
-    sock = socket(AF_INET, SOCK_STREAM, 0);
-    if (sock < 0)
-	return -errno;
-    
-    if (connect(sock, (struct sockaddr *) &ad, sizeof(ad)) < 0)
+    hostres = gethostinfo(host, clientPort);
+    for (res = hostres; res; res = res->ai_next)
     {
-	close(sock);
-	return -errno;
+      sock = socket(res->ai_family, res->ai_socktype, res->ai_protocol);
+      if (sock < 0)
+        continue;
+      if (connect(sock, res->ai_addr, res->ai_addrlen) == 0)
+        break;
+      close(sock);
+      return -errno;
     }
-    
+    freeaddrinfo(hostres);
+    if (res == NULL)
+      return -1;
+
     return sock;
 }
 
-
 int SockPrintf(int sock, char *format,...)
 {
     va_list ap;
@@ -136,4 +116,22 @@
     printf("%s", cbuf);
     fflush(stdout);
 #endif
+}
+
+/* Stolen from FreeBSD's whois client, modified for jupe by W. Campbell */
+static struct addrinfo * gethostinfo(char const *host, int port)
+{
+        struct addrinfo hints, *res;
+        int error;
+        char portbuf[6];
+
+        memset(&hints, 0, sizeof(hints));
+        hints.ai_flags = 0;
+        hints.ai_family = AF_UNSPEC;
+        hints.ai_socktype = SOCK_STREAM;
+        snprintf(portbuf, 6, "%d", port);
+        error = getaddrinfo(host, portbuf, &hints, &res);
+        if (error)
+                return (NULL);
+        return (res);
 }
